==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXInfo.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXInfo;no warnings;($NXFeatures=(""));(
$checkLocalBySystemdSessions=(0x00a4+ 5239-0x151b));($osPreferSsOverNetstat=
(0x14fb+ 4395-0x2626));sub getHostInfo{__checkNxFeatures ();(my $retval=
libnxh::NXGetHostnameInfo ());Logger::debug2 (((
"\x48\x6f\x73\x74\x6e\x61\x6d\x65\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$retval)."\x2e"));return ($retval);}sub getHwInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetHwInfo ());Logger::debug2 (((
"\x48\x77\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20".$retval).
"\x2e"));return ($retval);}sub getOsInfo{__checkNxFeatures ();(my $retval=
libnxh::NXGetOsInfo ());Logger::debug2 (((
"\x4f\x73\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20".$retval).
"\x2e"));return ($retval);}sub getDistroInfo{__checkNxFeatures ();(my $retval=
libnxh::NXGetDistroInfo ());Logger::debug2 (((
"\x44\x69\x73\x74\x72\x6f\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$retval)."\x2e"));return ($retval);}sub getKernelInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetKernelInfo ());Logger::debug2 (((
"\x4b\x65\x72\x6e\x65\x6c\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$retval)."\x2e"));return ($retval);}sub getArchInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetArchInfo ());Logger::debug2 (((
"\x41\x72\x63\x68\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20".
$retval)."\x2e"));return ($retval);}sub getCpuInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetCpuInfo ());Logger::debug2 (((
"\x43\x70\x75\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20".$retval).
"\x2e"));return ($retval);}sub getMemInfo{__checkNxFeatures ();(my $buffer=(
"\x20" x (0x0f48+ 161-0x0fc9)));(my $ret=libnxh::NXGetMemInfo ($buffer));if ((
$ret!=(-(0x0231+ 600-0x0488)))){($buffer=~ s/\D//g );Logger::debug2 (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x47\x65\x74\x4d\x65\x6d\x49\x6e\x66\x6f\x3a\x20\x42\x75\x66\x66\x65\x72\x20\x63\x6f\x6e\x74\x61\x69\x6e\x73\x20\x5b"
.$buffer)."\x5d"));}else{(my $errNum=libnxh::NXGetError ());(my $errString=
libnxh::NXGetErrorString ());Logger::error (((((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x47\x65\x74\x4d\x65\x6d\x49\x6e\x66\x6f\x20\x66\x61\x69\x6c\x65\x64\x20\x77\x69\x74\x68\x20"
.$errNum)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errString)."\x2e"));
main::nxexit ();}return ($buffer);}sub getSupportInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetSupportInfo ());Logger::debug2 (((
"\x53\x75\x70\x70\x6f\x72\x74\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$retval)."\x2e"));return ($retval);}sub __checkNxFeatures{if (($NXFeatures eq 
(""))){($NXFeatures=(0x04f8+ 4093-0x14f4));if (((libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53")eq (""))or (
libnxh::NXTransGetEnvironment ("\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e")eq 
("")))){Logger::debug (
"\x55\x70\x64\x61\x74\x69\x6e\x67\x20\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53\x20\x61\x6e\x64\x20\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e\x20\x62\x65\x63\x61\x75\x73\x65\x20\x69\x74\x20\x77\x61\x73\x6e\x27\x74\x20\x67\x69\x76\x65\x6e\x20\x62\x79\x20\x70\x61\x72\x65\x6e\x74\x2e"
);setNxFeatures ();setNxVersion ();}}return ((0x1400+ 1485-0x19cc));}sub 
getNxFeatures{(my $feat=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53"));Logger::debug (((
"\x46\x65\x61\x74\x75\x72\x65\x73\x20\x6f\x66\x20\x4e\x58\x20".$feat)."\x2e"));
return ($feat);}sub setNxFeatures{libnxh::NXTransSetEnvironment (
"\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53",(""));(my $hostname=getHostInfo 
());(my $model=getHwInfo ());libnxh::NXProcessPurgeArg ($model);(my $platform=
getOsInfo ());(my $flavor=getDistroInfo ());(my $kernel=getKernelInfo ());(my $architecture
=getArchInfo ());(my $processors=getCpuInfo ());(my $memory=getMemInfo ());(my $support
=getSupportInfo ());(my $feat=(((((((((((((((($hostname."\x2c").$model)."\x2c").
$platform)."\x2c").$flavor)."\x2c").$kernel)."\x2c").$architecture)."\x2c").
$processors)."\x2c").$memory)."\x2c").$support));Logger::debug (
"\x55\x70\x64\x61\x74\x69\x6e\x67\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3a\x20\x73\x65\x74\x74\x69\x6e\x67\x20\x75\x70\x20\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53\x2e"
);Logger::debug (("\x4e\x65\x77\x20\x76\x61\x6c\x75\x65\x3a\x20".$feat));
libnxh::NXTransSetEnvironment ("\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53",
$feat);($NXFeatures=(0x0648+ 2189-0x0ed4));return ($feat);}sub getNxVersion{(my $version
=libnxh::NXGetVersionInfo ());Logger::debug2 (((
"\x56\x65\x72\x73\x69\x6f\x6e\x20\x6f\x66\x20\x4e\x58\x20".$version)."\x2e"));
return ($version);}sub setNxVersion{libnxh::NXTransSetEnvironment (
"\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e",(""));(my $version=
libnxh::NXGetVersionInfo ());Logger::debug (
"\x55\x70\x64\x61\x74\x69\x6e\x67\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3a\x20\x73\x65\x74\x74\x69\x6e\x67\x20\x75\x70\x20\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e"
);Logger::debug (("\x4e\x65\x77\x20\x76\x61\x6c\x75\x65\x3a\x20".$version));
libnxh::NXTransSetEnvironment ("\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e",
$version);}sub isArchitecture64Bit{if (defined ($architectureIs64Bit)){return (
$architectureIs64Bit);}(my $architecture=getArchInfo ());if (($architecture=~ /x86_64/ )
){($architectureIs64Bit=(0x07b4+ 516-0x09b7));return ((0x0ef8+ 561-0x1128));}
else{($architectureIs64Bit=(0x076f+ 3879-0x1696));return ((0x067b+ 2225-0x0f2c))
;}}sub setVariablesBasedOnDistributionAndKernel{(my $distro=lc (getDistroInfo ()
));(my $kernel=getKernelInfo ());if (($distro=~ /fedora/ )){if (($kernel=~ /^4/ )
){setVariablesForFedora22 ();}}if (($distro=~ /opensuse/ )){
setVariablesForOpenSUSE ();}}sub setVariablesForFedora22{Logger::debug (
"\x46\x65\x64\x6f\x72\x61\x20\x32\x32\x20\x64\x65\x74\x65\x63\x74\x65\x64\x2e");
($checkLocalBySystemdSessions=(0x1818+ 2786-0x22f9));}sub 
setVariablesForOpenSUSE{Logger::debug (
"\x4f\x70\x65\x6e\x53\x55\x53\x45\x20\x64\x65\x74\x65\x63\x74\x65\x64\x2e");
setOsPreferSsOverNetstat ();}sub shouldCheckLocalBySystemdSessions{if ((
$checkLocalBySystemdSessions==(0x1a49+ 1577-0x2071))){return (
(0x0648+ 2353-0x0f78));}return ((0x0442+ 3415-0x1199));}sub 
setOsPreferSsOverNetstat{($osPreferSsOverNetstat=(0x192c+ 807-0x1c52));}sub 
doesOsPreferSsOverNetstat{if (($osPreferSsOverNetstat==(0x01c7+ 1651-0x0839))){
return ((0x11b7+ 1289-0x16bf));}return ((0x1f62+ 1437-0x24ff));}return (
(0x00f0+ 9378-0x2591));

==> nomachine-7.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXInfo.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXInfo;no warnings;($NXFeatures=(""));(
$checkLocalBySystemdSessions=(0x11a8+ 4445-0x2305));($osPreferSsOverNetstat=
(0x200d+ 542-0x222b));sub getHostInfo{__checkNxFeatures ();(my $retval=
libnxh::NXGetHostnameInfo ());Logger::debug2 (((
"\x48\x6f\x73\x74\x6e\x61\x6d\x65\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$retval)."\x2e"));return ($retval);}sub getHwInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetHwInfo ());Logger::debug2 (((
"\x48\x77\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20".$retval).
"\x2e"));return ($retval);}sub getOsInfo{__checkNxFeatures ();(my $retval=
libnxh::NXGetOsInfo ());Logger::debug2 (((
"\x4f\x73\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20".$retval).
"\x2e"));return ($retval);}sub getDistroInfo{__checkNxFeatures ();(my $retval=
libnxh::NXGetDistroInfo ());Logger::debug2 (((
"\x44\x69\x73\x74\x72\x6f\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$retval)."\x2e"));return ($retval);}sub getKernelInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetKernelInfo ());Logger::debug2 (((
"\x4b\x65\x72\x6e\x65\x6c\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$retval)."\x2e"));return ($retval);}sub getArchInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetArchInfo ());Logger::debug2 (((
"\x41\x72\x63\x68\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20".
$retval)."\x2e"));return ($retval);}sub getCpuInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetCpuInfo ());Logger::debug2 (((
"\x43\x70\x75\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20".$retval).
"\x2e"));return ($retval);}sub getMemInfo{__checkNxFeatures ();(my $buffer=(
"\x20" x (0x0766+ 2245-0x100b)));(my $ret=libnxh::NXGetMemInfo ($buffer));if ((
$ret!=(-(0x0142+ 5567-0x1700)))){($buffer=~ s/\D//g );Logger::debug2 (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x47\x65\x74\x4d\x65\x6d\x49\x6e\x66\x6f\x3a\x20\x42\x75\x66\x66\x65\x72\x20\x63\x6f\x6e\x74\x61\x69\x6e\x73\x20\x5b"
.$buffer)."\x5d"));}else{(my $errNum=libnxh::NXGetError ());(my $errString=
libnxh::NXGetErrorString ());Logger::error (((((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x47\x65\x74\x4d\x65\x6d\x49\x6e\x66\x6f\x20\x66\x61\x69\x6c\x65\x64\x20\x77\x69\x74\x68\x20"
.$errNum)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errString)."\x2e"));
main::nxexit ();}return ($buffer);}sub getSupportInfo{__checkNxFeatures ();(my $retval
=libnxh::NXGetSupportInfo ());Logger::debug2 (((
"\x53\x75\x70\x70\x6f\x72\x74\x49\x6e\x66\x6f\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$retval)."\x2e"));return ($retval);}sub __checkNxFeatures{if (($NXFeatures eq 
(""))){($NXFeatures=(0x05b2+ 5440-0x1af1));if (((libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53")eq (""))or (
libnxh::NXTransGetEnvironment ("\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e")eq 
("")))){Logger::debug (
"\x55\x70\x64\x61\x74\x69\x6e\x67\x20\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53\x20\x61\x6e\x64\x20\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e\x20\x62\x65\x63\x61\x75\x73\x65\x20\x69\x74\x20\x77\x61\x73\x6e\x27\x74\x20\x67\x69\x76\x65\x6e\x20\x62\x79\x20\x70\x61\x72\x65\x6e\x74\x2e"
);setNxFeatures ();setNxVersion ();}}return ((0x029c+ 619-0x0506));}sub 
getNxFeatures{(my $feat=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53"));Logger::debug (((
"\x46\x65\x61\x74\x75\x72\x65\x73\x20\x6f\x66\x20\x4e\x58\x20".$feat)."\x2e"));
return ($feat);}sub setNxFeatures{libnxh::NXTransSetEnvironment (
"\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53",(""));(my $hostname=getHostInfo 
());(my $model=getHwInfo ());libnxh::NXProcessPurgeArg ($model);(my $platform=
getOsInfo ());(my $flavor=getDistroInfo ());(my $kernel=getKernelInfo ());(my $architecture
=getArchInfo ());(my $processors=getCpuInfo ());(my $memory=getMemInfo ());(my $support
=getSupportInfo ());(my $feat=(((((((((((((((($hostname."\x2c").$model)."\x2c").
$platform)."\x2c").$flavor)."\x2c").$kernel)."\x2c").$architecture)."\x2c").
$processors)."\x2c").$memory)."\x2c").$support));Logger::debug (
"\x55\x70\x64\x61\x74\x69\x6e\x67\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3a\x20\x73\x65\x74\x74\x69\x6e\x67\x20\x75\x70\x20\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53\x2e"
);Logger::debug (("\x4e\x65\x77\x20\x76\x61\x6c\x75\x65\x3a\x20".$feat));
libnxh::NXTransSetEnvironment ("\x4e\x58\x5f\x46\x45\x41\x54\x55\x52\x45\x53",
$feat);($NXFeatures=(0x029f+ 3360-0x0fbe));return ($feat);}sub getNxVersion{(my $version
=libnxh::NXGetVersionInfo ());Logger::debug2 (((
"\x56\x65\x72\x73\x69\x6f\x6e\x20\x6f\x66\x20\x4e\x58\x20".$version)."\x2e"));
return ($version);}sub setNxVersion{libnxh::NXTransSetEnvironment (
"\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e",(""));(my $version=
libnxh::NXGetVersionInfo ());Logger::debug (
"\x55\x70\x64\x61\x74\x69\x6e\x67\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3a\x20\x73\x65\x74\x74\x69\x6e\x67\x20\x75\x70\x20\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e"
);Logger::debug (("\x4e\x65\x77\x20\x76\x61\x6c\x75\x65\x3a\x20".$version));
libnxh::NXTransSetEnvironment ("\x4e\x58\x5f\x56\x45\x52\x53\x49\x4f\x4e",
$version);}sub isArchitecture64Bit{if (defined ($architectureIs64Bit)){return (
$architectureIs64Bit);}(my $architecture=getArchInfo ());if (($architecture=~ /x86_64/ )
){($architectureIs64Bit=(0x1181+ 2886-0x1cc6));return ((0x04ed+ 6844-0x1fa8));}
else{($architectureIs64Bit=(0x003d+ 6944-0x1b5d));return ((0x0152+ 5334-0x1628))
;}}sub setVariablesBasedOnDistributionAndKernel{(my $distro=lc (getDistroInfo ()
));(my $kernel=getKernelInfo ());if (($distro=~ /fedora/ )){if (($kernel=~ /^4/ )
){setVariablesForFedora22 ();}}if (($distro=~ /opensuse/ )){
setVariablesForOpenSUSE ();}}sub setVariablesForFedora22{Logger::debug (
"\x46\x65\x64\x6f\x72\x61\x20\x32\x32\x20\x64\x65\x74\x65\x63\x74\x65\x64\x2e");
($checkLocalBySystemdSessions=(0x02e1+ 8229-0x2305));}sub 
setVariablesForOpenSUSE{Logger::debug (
"\x4f\x70\x65\x6e\x53\x55\x53\x45\x20\x64\x65\x74\x65\x63\x74\x65\x64\x2e");
setOsPreferSsOverNetstat ();}sub shouldCheckLocalBySystemdSessions{if ((
$checkLocalBySystemdSessions==(0x06b9+ 554-0x08e2))){return (
(0x1070+ 1244-0x154b));}return ((0x0222+ 1579-0x084d));}sub 
setOsPreferSsOverNetstat{($osPreferSsOverNetstat=(0x05d9+ 6014-0x1d56));}sub 
doesOsPreferSsOverNetstat{if (($osPreferSsOverNetstat==(0x0c95+ 5028-0x2038))){
return ((0x068d+ 3828-0x1580));}return ((0x04d1+ 1469-0x0a8e));}return (
(0x14ac+ 1383-0x1a12));
